==> react-atom-table-1.11.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import cx from 'classnames';
var CELL_TYPE = {
  header: 'th',
  data: 'td'
};
var CELL_PADDING = {
  xs: 'xs',
  s: 's',
  m: 'm',
  l: 'l',
  xl: 'l'
};

var AtomTable = function AtomTable(_ref) {
  var _cx, _cx2, _cx3;

  var _ref$head = _ref.head,
      head = _ref$head === void 0 ? [] : _ref$head,
      body = _ref.body,
      _ref$foot = _ref.foot,
      foot = _ref$foot === void 0 ? [] : _ref$foot,
      fullWidth = _ref.fullWidth,
      cellPadding = _ref.cellPadding,
      borderBottom = _ref.borderBottom,
      onRowClick = _ref.onRowClick,
      zebraStriped = _ref.zebraStriped;
  var hasHead = Boolean(head.length);
  var hasFoot = Boolean(foot.length);
  var isRowActionable = Boolean(onRowClick);
  var baseClass = 'react-AtomTable';
  var tableClass = cx("" + baseClass, (_cx = {}, _cx[baseClass + "--fullWidth"] = Boolean(fullWidth), _cx));
  var headerClass = cx(baseClass + "-cell", baseClass + "-headerCell", (_cx2 = {}, _cx2[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx2));
  var rowClass = cx(baseClass + "-row", (_cx3 = {}, _cx3[baseClass + "-row--actionable"] = isRowActionable, _cx3[baseClass + "-row--zebraStriped"] = zebraStriped, _cx3));

  var handleOnRowClick = function handleOnRowClick(index) {
    return onRowClick(index);
  };

  return /*#__PURE__*/_jsxs("table", {
    className: tableClass,
    children: [hasHead && /*#__PURE__*/_jsx("thead", {
      children: /*#__PURE__*/_jsx("tr", {
        children: head.map(function (element, index) {
          return /*#__PURE__*/_jsx("th", {
            className: headerClass,
            children: element
          }, index);
        })
      })
    }), /*#__PURE__*/_jsx("tbody", {
      children: body.map(function (row, index) {
        return /*#__PURE__*/_jsx("tr", _extends({
          className: rowClass
        }, isRowActionable && {
          onClick: function onClick() {
            return handleOnRowClick(index);
          }
        }, {
          children: row.map(function (cell, index) {
            var _cx4;

            var _cell$type = cell.type,
                Element = _cell$type === void 0 ? CELL_TYPE.data : _cell$type,
                _cell$content = cell.content,
                content = _cell$content === void 0 ? '' : _cell$content,
                isNowrap = cell.isNowrap,
                _cell$colspan = cell.colspan,
                colspan = _cell$colspan === void 0 ? 1 : _cell$colspan;
            var cellClassName = cx(baseClass + "-cell", (_cx4 = {}, _cx4[baseClass + "-cell--noWrap"] = isNowrap, _cx4[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx4[baseClass + "-cell--borderBottom"] = Boolean(borderBottom), _cx4));
            return /*#__PURE__*/_jsx(Element, {
              className: cellClassName,
              colSpan: colspan,
              children: content
            }, index);
          })
        }), index);
      })
    }), hasFoot && /*#__PURE__*/_jsx("tfoot", {
      children: /*#__PURE__*/_jsx("tr", {
        children: foot.map(function (element, index) {
          return /*#__PURE__*/_jsx("td", {
            className: baseClass + "-cell",
            children: element
          }, index);
        })
      })
    })]
  });
};

AtomTable.displayName = 'AtomTable';
export { CELL_TYPE as atomTableCellTypes, CELL_PADDING as atomTableCellPadding };
export default AtomTable;

==> react-atom-table-1.12.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import cx from 'classnames';
import { BASE_CLASS, CELL_BASE_CLASS, ROW_BASE_CLASS, TABLE_CELL_PADDING, TABLE_CELL_TYPE } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var AtomTable = function AtomTable(_ref) {
  var _cx, _cx2, _cx3;

  var _ref$head = _ref.head,
      head = _ref$head === void 0 ? [] : _ref$head,
      body = _ref.body,
      _ref$foot = _ref.foot,
      foot = _ref$foot === void 0 ? [] : _ref$foot,
      fullWidth = _ref.fullWidth,
      cellPadding = _ref.cellPadding,
      borderBottom = _ref.borderBottom,
      onRowClick = _ref.onRowClick,
      zebraStriped = _ref.zebraStriped;
  var hasHead = Boolean(head.length);
  var hasFoot = Boolean(foot.length);
  var isRowActionable = Boolean(onRowClick);
  var tableClass = cx("" + BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--fullWidth"] = Boolean(fullWidth), _cx));
  var headerClass = cx("" + CELL_BASE_CLASS, BASE_CLASS + "-headerCell", (_cx2 = {}, _cx2[CELL_BASE_CLASS + "--" + cellPadding] = Boolean(cellPadding), _cx2));
  var rowClass = cx("" + ROW_BASE_CLASS, (_cx3 = {}, _cx3[ROW_BASE_CLASS + "--actionable"] = isRowActionable, _cx3[ROW_BASE_CLASS + "--zebraStriped"] = zebraStriped, _cx3));

  var handleOnRowClick = function handleOnRowClick(index) {
    return onRowClick(index);
  };

  return /*#__PURE__*/_jsxs("table", {
    className: tableClass,
    children: [hasHead && /*#__PURE__*/_jsx("thead", {
      children: /*#__PURE__*/_jsx("tr", {
        children: head.map(function (element, index) {
          return /*#__PURE__*/_jsx("th", {
            className: headerClass,
            children: element
          }, index);
        })
      })
    }), /*#__PURE__*/_jsx("tbody", {
      children: body.map(function (row, index) {
        return /*#__PURE__*/_jsx("tr", _extends({
          className: rowClass
        }, isRowActionable && {
          onClick: function onClick() {
            return handleOnRowClick(index);
          }
        }, {
          children: row.map(function (cell, index) {
            var _cx4;

            var _cell$type = cell.type,
                Element = _cell$type === void 0 ? TABLE_CELL_TYPE.data : _cell$type,
                _cell$content = cell.content,
                content = _cell$content === void 0 ? '' : _cell$content,
                isNowrap = cell.isNowrap,
                _cell$colspan = cell.colspan,
                colspan = _cell$colspan === void 0 ? 1 : _cell$colspan;
            var cellClassName = cx("" + CELL_BASE_CLASS, (_cx4 = {}, _cx4[CELL_BASE_CLASS + "--noWrap"] = isNowrap, _cx4[CELL_BASE_CLASS + "--" + cellPadding] = Boolean(cellPadding), _cx4[CELL_BASE_CLASS + "--borderBottom"] = Boolean(borderBottom), _cx4));
            return /*#__PURE__*/_jsx(Element, {
              className: cellClassName,
              colSpan: colspan,
              children: content
            }, index);
          })
        }), index);
      })
    }), hasFoot && /*#__PURE__*/_jsx("tfoot", {
      children: /*#__PURE__*/_jsx("tr", {
        children: foot.map(function (element, index) {
          return /*#__PURE__*/_jsx("td", {
            className: "" + CELL_BASE_CLASS,
            children: element
          }, index);
        })
      })
    })]
  });
};

AtomTable.displayName = 'AtomTable';
export { TABLE_CELL_TYPE as atomTableCellTypes, TABLE_CELL_PADDING as atomTableCellPadding };
export default AtomTable;
